]> sigrok.org Git - libsigrok.git/blobdiff - strutil.c
build: Portability fixes.
[libsigrok.git] / strutil.c
index 0438c5ecc03cf74516c1be3bda1f8876ed419758..54dc1f39df50123ac985a158bc3d9ca425f9f5a6 100644 (file)
--- a/strutil.c
+++ b/strutil.c
@@ -25,7 +25,9 @@
 #include "libsigrok.h"
 #include "libsigrok-internal.h"
 
+/** @cond PRIVATE */
 #define LOG_PREFIX "strutil"
+/** @endcond */
 
 /**
  * @file
@@ -44,7 +46,7 @@
 /**
  * @private
  *
* Convert a string representation of a numeric value to a long integer. The
  * conversion is strict and will fail if the complete string does not represent
  * a valid long integer. The function sets errno according to the details of the
  * failure.
@@ -52,7 +54,8 @@
  * @param str The string representation to convert.
  * @param ret Pointer to long where the result of the conversion will be stored.
  *
- * @return SR_OK if conversion is successful, otherwise SR_ERR.
+ * @retval SR_OK Conversion successful.
+ * @retval SR_ERR Failure.
  *
  * @since 0.3.0
  */
@@ -62,7 +65,7 @@ SR_PRIV int sr_atol(const char *str, long *ret)
        char *endptr = NULL;
 
        errno = 0;
-       tmp = strtol(str, &endptr, 0);
+       tmp = strtol(str, &endptr, 10);
 
        if (!endptr || *endptr || errno) {
                if (!errno)
@@ -77,7 +80,7 @@ SR_PRIV int sr_atol(const char *str, long *ret)
 /**
  * @private
  *
* Convert a string representation of a numeric value to an integer. The
  * conversion is strict and will fail if the complete string does not represent
  * a valid integer. The function sets errno according to the details of the
  * failure.
@@ -85,7 +88,8 @@ SR_PRIV int sr_atol(const char *str, long *ret)
  * @param str The string representation to convert.
  * @param ret Pointer to int where the result of the conversion will be stored.
  *
- * @return SR_OK if conversion is successful, otherwise SR_ERR.
+ * @retval SR_OK Conversion successful.
+ * @retval SR_ERR Failure.
  *
  * @since 0.3.0
  */
@@ -116,7 +120,8 @@ SR_PRIV int sr_atoi(const char *str, int *ret)
  * @param str The string representation to convert.
  * @param ret Pointer to double where the result of the conversion will be stored.
  *
- * @return SR_OK if conversion is successful, otherwise SR_ERR.
+ * @retval SR_OK Conversion successful.
+ * @retval SR_ERR Failure.
  *
  * @since 0.3.0
  */
@@ -149,7 +154,8 @@ SR_PRIV int sr_atod(const char *str, double *ret)
  * @param str The string representation to convert.
  * @param ret Pointer to float where the result of the conversion will be stored.
  *
- * @return SR_OK if conversion is successful, otherwise SR_ERR.
+ * @retval SR_OK Conversion successful.
+ * @retval SR_ERR Failure.
  *
  * @since 0.3.0
  */
@@ -180,7 +186,8 @@ SR_PRIV int sr_atof(const char *str, float *ret)
  * @param str The string representation to convert.
  * @param ret Pointer to float where the result of the conversion will be stored.
  *
- * @return SR_OK if conversion is successful, otherwise SR_ERR.
+ * @retval SR_OK Conversion successful.
+ * @retval SR_ERR Failure.
  *
  * @since 0.3.0
  */
@@ -226,6 +233,8 @@ SR_PRIV int sr_atof_ascii(const char *str, float *ret)
  * @return A g_try_malloc()ed string representation of the samplerate value,
  *         or NULL upon errors. The caller is responsible to g_free() the
  *         memory.
+ *
+ * @since 0.2.0
  */
 SR_API char *sr_si_string_u64(uint64_t x, const char *unit)
 {
@@ -266,6 +275,8 @@ SR_API char *sr_si_string_u64(uint64_t x, const char *unit)
  * @return A g_try_malloc()ed string representation of the samplerate value,
  *         or NULL upon errors. The caller is responsible to g_free() the
  *         memory.
+ *
+ * @since 0.1.0
  */
 SR_API char *sr_samplerate_string(uint64_t samplerate)
 {
@@ -283,6 +294,8 @@ SR_API char *sr_samplerate_string(uint64_t samplerate)
  * @return A g_try_malloc()ed string representation of the frequency value,
  *         or NULL upon errors. The caller is responsible to g_free() the
  *         memory.
+ *
+ * @since 0.1.0
  */
 SR_API char *sr_period_string(uint64_t frequency)
 {
@@ -326,6 +339,8 @@ SR_API char *sr_period_string(uint64_t frequency)
  * @return A g_try_malloc()ed string representation of the voltage value,
  *         or NULL upon errors. The caller is responsible to g_free() the
  *         memory.
+ *
+ * @since 0.2.0
  */
 SR_API char *sr_voltage_string(uint64_t v_p, uint64_t v_q)
 {
@@ -353,100 +368,6 @@ SR_API char *sr_voltage_string(uint64_t v_p, uint64_t v_q)
        return o;
 }
 
-/**
- * Parse a trigger specification string.
- *
- * @param sdi The device instance for which the trigger specification is
- *            intended. Must not be NULL. Also, sdi->driver and
- *            sdi->driver->info_get must not be NULL.
- * @param triggerstring The string containing the trigger specification for
- *        one or more probes of this device. Entries for multiple probes are
- *        comma-separated. Triggers are specified in the form key=value,
- *        where the key is a probe number (or probe name) and the value is
- *        the requested trigger type. Valid trigger types currently
- *        include 'r' (rising edge), 'f' (falling edge), 'c' (any pin value
- *        change), '0' (low value), or '1' (high value).
- *        Example: "1=r,sck=f,miso=0,7=c"
- *
- * @return Pointer to a list of trigger types (strings), or NULL upon errors.
- *         The pointer list (if non-NULL) has as many entries as the
- *         respective device has probes (all physically available probes,
- *         not just enabled ones). Entries of the list which don't have
- *         a trigger value set in 'triggerstring' are NULL, the other entries
- *         contain the respective trigger type which is requested for the
- *         respective probe (e.g. "r", "c", and so on).
- */
-SR_API char **sr_parse_triggerstring(const struct sr_dev_inst *sdi,
-                                    const char *triggerstring)
-{
-       GSList *l;
-       GVariant *gvar;
-       struct sr_probe *probe;
-       int max_probes, probenum, i;
-       char **tokens, **triggerlist, *trigger, *tc;
-       const char *trigger_types;
-       gboolean error;
-
-       max_probes = g_slist_length(sdi->probes);
-       error = FALSE;
-
-       if (!(triggerlist = g_try_malloc0(max_probes * sizeof(char *)))) {
-               sr_err("%s: triggerlist malloc failed", __func__);
-               return NULL;
-       }
-
-       if (sdi->driver->config_list(SR_CONF_TRIGGER_TYPE,
-                               &gvar, sdi, NULL) != SR_OK) {
-               sr_err("%s: Device doesn't support any triggers.", __func__);
-               return NULL;
-       }
-       trigger_types = g_variant_get_string(gvar, NULL);
-
-       tokens = g_strsplit(triggerstring, ",", max_probes);
-       for (i = 0; tokens[i]; i++) {
-               probenum = -1;
-               for (l = sdi->probes; l; l = l->next) {
-                       probe = (struct sr_probe *)l->data;
-                       if (probe->enabled
-                               && !strncmp(probe->name, tokens[i],
-                                       strlen(probe->name))) {
-                               probenum = probe->index;
-                               break;
-                       }
-               }
-
-               if (probenum < 0 || probenum >= max_probes) {
-                       sr_err("Invalid probe.");
-                       error = TRUE;
-                       break;
-               }
-
-               if ((trigger = strchr(tokens[i], '='))) {
-                       for (tc = ++trigger; *tc; tc++) {
-                               if (strchr(trigger_types, *tc) == NULL) {
-                                       sr_err("Unsupported trigger "
-                                              "type '%c'.", *tc);
-                                       error = TRUE;
-                                       break;
-                               }
-                       }
-                       if (!error)
-                               triggerlist[probenum] = g_strdup(trigger);
-               }
-       }
-       g_strfreev(tokens);
-       g_variant_unref(gvar);
-
-       if (error) {
-               for (i = 0; i < max_probes; i++)
-                       g_free(triggerlist[i]);
-               g_free(triggerlist);
-               triggerlist = NULL;
-       }
-
-       return triggerlist;
-}
-
 /**
  * Convert a "natural" string representation of a size value to uint64_t.
  *
@@ -461,6 +382,8 @@ SR_API char **sr_parse_triggerstring(const struct sr_dev_inst *sdi,
  * @param size Pointer to uint64_t which will contain the string's size value.
  *
  * @return SR_OK upon success, SR_ERR upon errors.
+ *
+ * @since 0.1.0
  */
 SR_API int sr_parse_sizestring(const char *sizestring, uint64_t *size)
 {
@@ -526,6 +449,8 @@ SR_API int sr_parse_sizestring(const char *sizestring, uint64_t *size)
  * @todo Add support for "m" (minutes) and others.
  * @todo Add support for picoseconds?
  * @todo Allow both lower-case and upper-case? If no, document it.
+ *
+ * @since 0.1.0
  */
 SR_API uint64_t sr_parse_timestring(const char *timestring)
 {
@@ -552,6 +477,7 @@ SR_API uint64_t sr_parse_timestring(const char *timestring)
        return time_msec;
 }
 
+/** @since 0.1.0 */
 SR_API gboolean sr_parse_boolstring(const char *boolstr)
 {
        if (!boolstr)
@@ -566,6 +492,7 @@ SR_API gboolean sr_parse_boolstring(const char *boolstr)
        return FALSE;
 }
 
+/** @since 0.2.0 */
 SR_API int sr_parse_period(const char *periodstr, uint64_t *p, uint64_t *q)
 {
        char *s;
@@ -598,7 +525,7 @@ SR_API int sr_parse_period(const char *periodstr, uint64_t *p, uint64_t *q)
        return SR_OK;
 }
 
-
+/** @since 0.2.0 */
 SR_API int sr_parse_voltage(const char *voltstr, uint64_t *p, uint64_t *q)
 {
        char *s;
@@ -44,7 +46,7 @@
  * @private
  *
- * Convert a string representation of a numeric value to a long integer. The
+ * Convert a string representation of a numeric value (base 10) to a long integer. The
  * conversion is strict and will fail if the complete string does not represent
  * a valid long integer. The function sets errno according to the details of the
@@ -77,7 +80,7 @@ SR_PRIV int sr_atol(const char *str, long *ret)
  * @private
  *
- * Convert a string representation of a numeric value to an integer. The
+ * Convert a string representation of a numeric value (base 10) to an integer. The
  * conversion is strict and will fail if the complete string does not represent
  * a valid integer. The function sets errno according to the details of the